This function will generate an interactive dashboard of the annotated K2 Taxonomer results in a specified directory.
K2dashboard(
K2res,
analysis_name = "K2Taxonomer",
about = TRUE,
output_dir = "."
)Nothing. Writes files to a specified directory.
Reed ER, Monti S (2021). “Multi-resolution characterization of molecular taxonomies in bulk and single-cell transcriptomics data.” Nucleic Acids Research. doi:10.1093/nar/gkab552 , https://pubmed.ncbi.nlm.nih.gov/34226941/.