This function creates a plot for visualizing gene expression between partitions, either as a static plot or interactive with plotly.
plotGenePathway(
K2res,
feature,
node,
type = c("eMatDS", "eMat", "gMat"),
use_plotly = TRUE,
subsample = TRUE
)A K2 class object.
Character. A specific node identifier in K2res object.
Character. One of 'eMatDS' (default), 'eMat', or 'gMat'.
Logical. Whether to create a static plot, FALSE, or interactive plot, TRUE (default).
Logical. Whether to downsample the output object in order to save memory. This minimal impact on plot visual. Default is TRUE.
Character. Either a gene or gene set identifier.
Either a ggplot or ggplotly object.
Reed ER, Monti S (2021). “Multi-resolution characterization of molecular taxonomies in bulk and single-cell transcriptomics data.” Nucleic Acids Research. doi:10.1093/nar/gkab552 , https://pubmed.ncbi.nlm.nih.gov/34226941/.