This function takes an unlabeled dataset and two lists of must-link and cannot-link constraints as input and produce a clustering as output. This function was originally published in the 'conclust' package, https://github.com/cran/conclust, and was archived on CRAN on 2025-05-21, https://CRAN.R-project.org/package=conclust.
lcvqe(data, k, mustLink, cantLink, maxIter = 10)A vector that represents the labels (clusters) of the data points.
This algorithm finds a clustering that satisfies as many constraints as possible
Wagstaff K, Cardie C, Rogers S, Schrodl S (2001). “Constrained K-means Clustering with Background Knowledge.” In ICML, 577–584.