R/runDGEmods.R
runDGEmods.RdAdds differential analysis results to the output of K2tax().
runDGEmods(
K2res,
DGEmethod = NULL,
DGEexpThreshold = NULL,
vehicle = NULL,
variables = NULL,
block = NULL,
logCounts = NULL
)Character. Method for running differential gene expression analyses. Use one of either 'limma' (default) or 'mast'.
Numeric. A value between 0 and 1 indicating for filtering lowly expressed genes for partition-specific differential gene expression. Proportion of observations with counts > 0 in at least one subgroup at a specific partition.
The value in the cohort variable that contains the ID of observation to use as control. Default NULL if no vehicle to be used.
Character. Columns in meta data of 'object' to control for in differential analyses.
Character. Block parameter in limma for modeling higherarchical data structure, such as multiple observations per individual.
Logical. Whether or not expression values are log-scale counts or log normalized counts from RNA-seq. Default is TRUE.
An object of class K2.
Reed ER, Monti S (2021). “Multi-resolution characterization of molecular taxonomies in bulk and single-cell transcriptomics data.” Nucleic Acids Research. doi:10.1093/nar/gkab552 , https://pubmed.ncbi.nlm.nih.gov/34226941/. Ritchie ME, Phipson B, Wu D, Hu Y, Law CW, Shi W, Smyth GK (2015). “limma powers differential expression analyses for RNA-sequencing and microarray studies.” Nucleic Acids Research, 43(7), e47–e47. ISSN 1362-4962, 0305-1048, doi:10.1093/nar/gkv007 , http://academic.oup.com/nar/article/43/7/e47/2414268/limma-powers-differential-expression-analyses-for. Benjamini Y, Hochberg Y (1995). “Controlling the False Discovery Rate: A Practical and Powerful Approach to Multiple Testing.” Journal of the Royal Statistical Society: Series B (Methodological), 57(1), 289–300. ISSN 00359246, doi:10.1111/j.2517-6161.1995.tb02031.x , http://doi.wiley.com/10.1111/j.2517-6161.1995.tb02031.x.